@@ -15,7 +15,6 @@ import configparser
 import collections
 import traceback
 import functools
-import sys
 import shutil
 
 import sphinx.builders.text
@@ -84,25 +83,13 @@ from clasp import click
 import clasp.click_ext as clk
 import clasp.script_tools as cst
 
+"""{callback_help}"""
+
 @click.command()
 @click.argument('arg1')
-@clk.shared_decs(clk.command_decs('0.1'))
+@clk.shared_decs(clk.command_decs('0.1', wrap=True))
 def main(ctx, arg1, **kwargs):
-    """{callback_help}"""
-    if kwargs['opts']:
-        kwargs['opts'] = False
-        clk.echo_args(arg1, **kwargs)
-    else:
-        try:
-            pass
-        except click.Abort:
-            raise
-        except Exception as ex:
-            clk.print_except(ex, kwargs['debug'])
-    try:
-        clk.tmp_clean(ctx)
-    except Exception:
-        pass
+    pass
 
 if __name__ == '__main__':
     main()'''
@@ -114,6 +101,8 @@ from clasp import click
 import clasp.click_ext as clk
 import clasp.script_tools as cst
 
+"""{callback_help}"""
+
 @click.group()
 @clk.shared_decs(clk.main_decs('0.1'))
 def main(ctx, config, outconfig, configalias, inputalias):
@@ -123,20 +112,9 @@ def main(ctx, config, outconfig, configalias, inputalias):
 
 @main.command()
 @click.argument('arg1')
-@clk.shared_decs(clk.command_decs('0.1'))
+@clk.shared_decs(clk.command_decs('0.1', wrap=True))
 def XXX(ctx, arg1, **kwargs):
-    """{clasp.click_callbacks.__doc__}"""
-    if kwargs['opts']:
-        kwargs['opts'] = False
-        clk.echo_args(arg1, **kwargs)
-    else:
-        try:
-            pass
-        except click.Abort:
-            raise
-        except Exception as ex:
-            clk.print_except(ex, kwargs['debug'])
-    return 'XXX', kwargs, ctx
+    pass
 
 
 @main.resultcallback()
@@ -257,44 +235,6 @@ def click_ext(click):
     click.core.Command.format_help_text = format_help_text
     click.core.Command.format_options = format_options
 
-    import click._bashcomplete as _bc
-
-    def get_completion_script(prog_name, complete_var, shell):
-        cf_name = _bc._invalid_ident_char_re.sub('',
-                                                 prog_name.replace('-', '_'))
-        if shell == 'zsh':
-            script = _bc.COMPLETION_SCRIPT_ZSH
-        else:
-            script = COMPLETION_SCRIPT_BASH
-        return (script % {
-            'complete_func': '_%s_completion' % cf_name,
-            'script_names': prog_name,
-            'autocomplete_var': complete_var,
-        }).strip() + ';'
-
-    def bashcomplete(cli, prog_name, complete_var, complete_instr):
-        if complete_instr.startswith('source'):
-            shell = 'zsh' if complete_instr == 'source_zsh' else 'bash'
-            click.echo(get_completion_script(prog_name, complete_var, shell))
-            return True
-        elif complete_instr == 'complete' or complete_instr == 'complete_zsh':
-            return _bc.do_complete(cli, prog_name,
-                                   complete_instr == 'complete_zsh')
-        return False
-
-    def _bashcomplete(cmd, prog_name, complete_var=None):
-        """Internal handler for the bash completion support."""
-        if complete_var is None:
-            complete_var = '_%s_COMPLETE' % (prog_name.replace('-', '_'))
-            complete_var = complete_var.upper()
-        complete_instr = os.environ.get(complete_var)
-        if not complete_instr:
-            return
-        if bashcomplete(cmd, prog_name, complete_var, complete_instr):
-            click.core.fast_exit(1)
-
-    click.core._bashcomplete = _bashcomplete
-    click._bashcomplete.COMPLETION_SCRIPT_BASH = COMPLETION_SCRIPT_BASH
     return click
 
 
@@ -317,7 +257,7 @@ def wrap_command():
             cname = func.__name__
             try:
                 chain = ctx.parent.command.__dict__['chain']
-            except KeyError:
+            except (KeyError, AttributeError):
                 chain = False
             if chain:
                 kwargs['opts'] = kwargs['opts'] or ctx.parent.params['opts']
